@@ -39,4 +39,7 @@ PUPPET_VERSION_SSM_PARAM_NAME = 'service-catalog-puppet-version'
 
 
 SPOKE_LOCAL_PORTFOLIO_STATUS_SHARED = "shared"
-SPOKE_LOCAL_PORTFOLIO_STATUS_TERMINATED = "terminated"
\ No newline at end of file
+SPOKE_LOCAL_PORTFOLIO_STATUS_TERMINATED = "terminated"
+
+EXECUTION_MODE_ASYNC = 'async'
+EXECUTION_MODE_HUB = 'hub'
\ No newline at end of file
